@@ -3,7 +3,7 @@ package App::FirefoxMultiAccountContainersUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-21'; # DATE
 our $DIST = 'App-FirefoxMultiAccountContainersUtils'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -321,7 +321,6 @@ _
             'x.name.is_plural' => 1,
             'x.name.singular' => 'url',
             schema => ['array*', of=>'str*'],
-            req => 1,
             pos => 1,
             slurpy => 1,
         },
@@ -330,10 +329,17 @@ _
     },
     examples => [
         {
+            summary => 'Open two URLs in a container called "mycontainer"',
             argv => [qw|mycontainer www.example.com www.example.com/url2|],
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'If URL is not specified, will open a blank tab',
+            argv => [qw|mycontainer|],
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
     ],
     links => [
         {url=>'prog:open-browser'},
@@ -346,7 +352,7 @@ sub firefox_container {
     my $container = $args{container};
 
     my @urls;
-    for my $url0 (@{ $args{urls} }) {
+    for my $url0 (@{ $args{urls} || ["about:blank"] }) {
         my $url = "ext+container:";
         $url .= "name=" . URI::Escape::uri_escape($container);
         $url .= "&url=" . URI::Escape::uri_escape($url0);
@@ -374,7 +380,7 @@ App::FirefoxMultiAccountContainersUtils - Utilities related to Firefox Multi-Acc
 
 =head1 VERSION
 
-This document describes version 0.008 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-09-21.
+This document describes version 0.009 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-09-21.
 
 =head1 SYNOPSIS
 
@@ -413,13 +419,17 @@ Examples:
 
 =over
 
-=item * Example #1:
+=item * Open two URLs in a container called "mycontainer":
 
  firefox_container(
      container => "mycontainer",
    urls => ["www.example.com", "www.example.com/url2"]
  );
 
+=item * If URL is not specified, will open a blank tab:
+
+ firefox_container( container => "mycontainer");
+
 =back
 
 This utility opens a new firefox tab in a specific multi-account container. This
@@ -446,7 +456,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<profile> => I<firefox::local_profile_name>
 
-=item * B<urls>* => I<array[str]>
+=item * B<urls> => I<array[str]>
 
 
 =back
